@@ -16,8 +16,8 @@
 ###
 ### You should have received a copy of the GNU General Public
 ### License along with this program; if not, write to the Free
-### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-### MA 02111-1307, USA
+### Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+### MA 02110-1301, USA
 
 
 
@@ -55,7 +55,7 @@ qq <- function(x, data, ...)  UseMethod("qq")
 
 qq.formula <-
     function(x,
-             data = parent.frame(),
+             data = NULL,
              aspect = "fill",
              panel = "panel.qq",
              prepanel = NULL,
@@ -214,7 +214,7 @@ qq.formula <-
         dimnames(foo$packet.sizes) <- lapply(foo$condlevels, as.character)
     }
     cond.current.level <- rep(1, length(cond))
-    for (packet.number in seq(length = npackets))
+    for (packet.number in seq_len(npackets))
     {
         id <- compute.packet(cond, cond.current.level)
         foo$packet.sizes[packet.number] <- sum(id)
